<?php

namespace app\modules\tag;

use itguild\forms\builders\TextInputBuilder;
use kernel\app_modules\tag\models\Tag;
use kernel\helpers\Debug;
use kernel\helpers\Slug;
use kernel\Module;
use kernel\modules\menu\service\MenuService;
use kernel\Request;
use kernel\services\MigrationService;

class TagModule extends Module
{

    public MenuService $menuService;
    public MigrationService $migrationService;
    public function __construct()
    {
        $this->menuService = new MenuService();
        $this->migrationService = new MigrationService();
    }

    /**
     * @throws \Exception
     */
    public function init(): void
    {
        $this->migrationService->runAtPath("{KERNEL_APP_MODULES}/tag/migrations");

        $this->menuService->createItem([
            "label" => "Тэги",
            "url" => "/admin/tag",
            "slug" => "tag",
        ]);
    }

    public function deactivate(): void
    {
        $this->menuService->removeItemBySlug("tag");
    }

    public function formInputs(): void
    {
        $input = TextInputBuilder::build("tag", ['class' => 'form-control', 'placeholder' => 'Теги']);
        $input->setLabel("Теги");
        $input->create()->render();
    }

    public function saveInputs(string $entity, Request $request): void
    {
        $model = new Tag();
        $model->entity = $entity;
        $model->label = $request->post('tag');
        $model->status = Tag::ACTIVE_STATUS;
        $model->slug = Slug::createSlug($request->post('tag'), $model);
        $model->save();
    }
}